==> nb_utils-2.0.3.tar.gz: lib/src/widget_extensions.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';
import 'package:nb_utils/src/tap_translate.dart';

extension WidgetExtension on Widget {
  SizedBox withSize({double width = 0.0, double height = 0.0}) {
    return SizedBox(height: height, width: width, child: this);
  }

  SizedBox withWidth(double width) {
    return SizedBox(width: width, child: this);
  }

  SizedBox withHeight(double height) {
    return SizedBox(height: height, child: this);
  }

  ClipRRect cornerRadiusWithClipRRect(double radius) {
    return ClipRRect(borderRadius: BorderRadius.circular(radius), child: this);
  }

  Padding paddingSymmetric({double vertical = 0.0, double horizontal = 0.0}) {
    return Padding(padding: EdgeInsets.symmetric(vertical: vertical, horizontal: horizontal), child: this);
  }

  Padding paddingTop(double top) {
    return Padding(padding: EdgeInsets.only(top: top), child: this);
  }

  Padding paddingLeft(double left) {
    return Padding(padding: EdgeInsets.only(left: left), child: this);
  }

  Padding paddingRight(double right) {
    return Padding(padding: EdgeInsets.only(right: right), child: this);
  }

  Padding paddingBottom(double bottom) {
    return Padding(padding: EdgeInsets.only(bottom: bottom), child: this);
  }

  Padding paddingOnly({double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0}) {
    return Padding(padding: EdgeInsets.fromLTRB(left, top, right, bottom), child: this);
  }

  Padding paddingAll(double padding) {
    return Padding(padding: EdgeInsets.all(padding), child: this);
  }

  Widget visible(bool visible) {
    return visible ? this : SizedBox();
  }

  Visibility withVisibility(
    bool visible, {
    Widget replacement,
    bool maintainAnimation = false,
    bool maintainState = false,
    bool maintainSize = false,
    bool maintainSemantics = false,
    bool maintainInteractivity = false,
  }) {
    return Visibility(
      visible: visible,
      maintainAnimation: maintainAnimation,
      maintainInteractivity: maintainInteractivity,
      maintainSemantics: maintainSemantics,
      maintainSize: maintainSize,
      maintainState: maintainState,
      key: key,
      child: this,
      replacement: replacement ?? Container(),
    );
  }

  Widget opacity({@required double opacity, durationInSecond = 3}) {
    return AnimatedOpacity(opacity: opacity, duration: Duration(seconds: durationInSecond), child: this);
  }

  Widget rotate({@required double angle, bool transformHitTests = true, Offset origin}) {
    return Transform.rotate(origin: origin, angle: angle, transformHitTests: transformHitTests, child: this);
  }

  Widget center({double heightFactor, double widthFactor}) {
    return Center(heightFactor: heightFactor, widthFactor: widthFactor, child: this);
  }

  Container withRoundedCorners({Color backgroundColor = whiteColor, radius = 8.0}) {
    return Container(
      decoration: BoxDecoration(color: backgroundColor, borderRadius: BorderRadius.all(Radius.circular(double.parse(radius.toString()).toDouble()))),
      child: this,
    );
  }

  Container withShadow({Color shadowColor = Colors.grey, double blurRadius = 5.0, double spreadRadius = 1.0, Offset offset = const Offset(5.0, 5.0)}) {
    return Container(
      decoration: BoxDecoration(
        boxShadow: [
          BoxShadow(color: shadowColor, blurRadius: blurRadius, spreadRadius: spreadRadius, offset: offset),
        ],
      ),
      child: this,
    );
  }

  Widget onTapWithTranslateEffect({int millisecond = 300}) {
    return TapTranslate(child: this, milliseconds: millisecond);
  }

  Widget onTap(Function function, {BorderRadius borderRadius}) {
    if (borderRadius == null) borderRadius = BorderRadius.all(Radius.circular(0));
    return InkWell(
      onTap: function,
      child: this,
      borderRadius: borderRadius,
    );
  }

  launch<T>(context) {
    if (this is StatelessWidget || this is StatefulWidget) {
      Navigator.of(context).push(MaterialPageRoute<T>(builder: (_) => this));
    } else {
      throw Exception('Widget can be StatelessWidget or StatefulWidget');
    }
  }
}

==> nb_utils-2.0.5.tar.gz: lib/src/widget_extensions.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

extension WidgetExtension on Widget {
  SizedBox withSize({double width = 0.0, double height = 0.0}) {
    return SizedBox(height: height, width: width, child: this);
  }

  SizedBox withWidth(double width) {
    return SizedBox(width: width, child: this);
  }

  SizedBox withHeight(double height) {
    return SizedBox(height: height, child: this);
  }

  ClipRRect cornerRadiusWithClipRRect(double radius) {
    return ClipRRect(borderRadius: BorderRadius.circular(radius), child: this);
  }

  Padding paddingSymmetric({double vertical = 0.0, double horizontal = 0.0}) {
    return Padding(padding: EdgeInsets.symmetric(vertical: vertical, horizontal: horizontal), child: this);
  }

  Padding paddingTop(double top) {
    return Padding(padding: EdgeInsets.only(top: top), child: this);
  }

  Padding paddingLeft(double left) {
    return Padding(padding: EdgeInsets.only(left: left), child: this);
  }

  Padding paddingRight(double right) {
    return Padding(padding: EdgeInsets.only(right: right), child: this);
  }

  Padding paddingBottom(double bottom) {
    return Padding(padding: EdgeInsets.only(bottom: bottom), child: this);
  }

  Padding paddingOnly({double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0}) {
    return Padding(padding: EdgeInsets.fromLTRB(left, top, right, bottom), child: this);
  }

  Padding paddingAll(double padding) {
    return Padding(padding: EdgeInsets.all(padding), child: this);
  }

  Widget visible(bool visible) {
    return visible ? this : SizedBox();
  }

  Visibility withVisibility(
    bool visible, {
    Widget replacement,
    bool maintainAnimation = false,
    bool maintainState = false,
    bool maintainSize = false,
    bool maintainSemantics = false,
    bool maintainInteractivity = false,
  }) {
    return Visibility(
      visible: visible,
      maintainAnimation: maintainAnimation,
      maintainInteractivity: maintainInteractivity,
      maintainSemantics: maintainSemantics,
      maintainSize: maintainSize,
      maintainState: maintainState,
      key: key,
      child: this,
      replacement: replacement ?? Container(),
    );
  }

  Widget opacity({@required double opacity, durationInSecond = 3}) {
    return AnimatedOpacity(opacity: opacity, duration: Duration(seconds: durationInSecond), child: this);
  }

  Widget rotate({@required double angle, bool transformHitTests = true, Offset origin}) {
    return Transform.rotate(origin: origin, angle: angle, transformHitTests: transformHitTests, child: this);
  }

  Widget center({double heightFactor, double widthFactor}) {
    return Center(heightFactor: heightFactor, widthFactor: widthFactor, child: this);
  }

  Container withRoundedCorners({Color backgroundColor = whiteColor, radius = 8.0}) {
    return Container(
      decoration: BoxDecoration(color: backgroundColor, borderRadius: BorderRadius.all(Radius.circular(double.parse(radius.toString()).toDouble()))),
      child: this,
    );
  }

  Container withShadow({Color shadowColor = Colors.black12, blurRadius = 10, spreadRadius = 0, Offset offset = const Offset(0.0, 0.0)}) {
    return Container(
      decoration: BoxDecoration(
        boxShadow: [
          BoxShadow(
            color: shadowColor,
            blurRadius: blurRadius,
            spreadRadius: spreadRadius,
            offset: offset,
          ),
        ],
      ),
      child: this,
    );
  }

  Widget onTap(Function function, {BorderRadius borderRadius = const BorderRadius.all(Radius.circular(0))}) {
    return InkWell(
      onTap: function,
      child: this,
      borderRadius: borderRadius,
    );
  }

  launch<T>(context) {
    if (this is StatelessWidget || this is StatefulWidget) {
      Navigator.of(context).push(MaterialPageRoute<T>(builder: (_) => this));
    } else {
      throw Exception('Widget can be StatelessWidget or StatefulWidget');
    }
  }
}
